@@ -84,8 +84,9 @@ def create_quick_launch(api_root, org_id, project_id):
     return "{api_root}/{org_id}/{project_id}/runs/quick_launch".format(**locals())
 
 
-def upload_sign(api_root):
-    return "{api_root}/upload/sign".format(**locals())
+def resolve_quick_launch_inputs(api_root, org_id, project_id, quick_launch_id):
+    return "{api_root}/{org_id}/{project_id}/runs/quick_launch/" \
+           "{quick_launch_id}/resolve_inputs".format(**locals())
 
 
 def aws_upload():
@@ -112,6 +113,10 @@ def analyze_run(api_root, org_id):
     return "{api_root}/{org_id}/analyze_run".format(**locals())
 
 
+def analyze_launch_request(api_root, org_id):
+    return "{api_root}/{org_id}/analyze_run".format(**locals())
+
+
 def submit_run(api_root, org_id, project_id):
     return "{api_root}/{org_id}/{project_id}/runs".format(**locals())
 
@@ -119,6 +124,11 @@ def submit_run(api_root, org_id, project_id):
 def submit_launch_request(api_root, org_id, project_id):
     return "{api_root}/{org_id}/{project_id}/runs".format(**locals())
 
+
+def dataset_short(api_root, data_id):
+    return "{api_root}/datasets/{data_id}.json".format(**locals())
+
+
 def dataset(api_root, data_id, key):
     return "{api_root}/datasets/{data_id}.json?key={key}".format(**locals())
 
@@ -127,6 +137,14 @@ def datasets(api_root, org_id, project_id, run_id):
     return "{api_root}/{org_id}/{project_id}/runs/{run_id}/data".format(**locals())
 
 
+def upload_uri(api_root):
+    return "{api_root}/upload/make_upload_uri".format(**locals())
+
+
+def upload_datasets(api_root):
+    return "{api_root}/api/datasets".format(**locals())
+
+
 def preview_protocol(api_root):
     return "{api_root}/runs/preview".format(**locals())
 
@@ -160,3 +178,7 @@ def monitoring_data(api_root, data_type, instruction_id, grouping=None, start_ti
     if end_time:
         base_route += "&end_time={end_time}".format(**locals())
     return base_route
+
+
+def get_payment_methods(api_root, org_id):
+    return "{api_root}/{org_id}/payment_methods".format(**locals())
